summaryrefslogtreecommitdiffstats
path: root/kdeui/keditlistbox.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdeui/keditlistbox.h')
-rw-r--r--kdeui/keditlistbox.h84
1 files changed, 42 insertions, 42 deletions
diff --git a/kdeui/keditlistbox.h b/kdeui/keditlistbox.h
index bb27d89f7..e5b828caf 100644
--- a/kdeui/keditlistbox.h
+++ b/kdeui/keditlistbox.h
@@ -20,8 +20,8 @@
#ifndef KEDITLISTBOX_H
#define KEDITLISTBOX_H
-#include <qgroupbox.h>
-#include <qlistbox.h>
+#include <tqgroupbox.h>
+#include <tqlistbox.h>
#include <kdelibs_export.h>
@@ -47,7 +47,7 @@ class KDEUI_EXPORT KEditListBox : public QGroupBox
Q_SETS( Button )
Q_PROPERTY( Button buttons READ buttons WRITE setButtons )
- Q_PROPERTY( QStringList items READ items WRITE setItems )
+ Q_PROPERTY( TQStringList items READ items WRITE setItems )
public:
/**
@@ -62,19 +62,19 @@ public:
KDEUI_EXPORT CustomEditor()
: m_representationWidget( 0L ),
m_lineEdit( 0L ) {}
- KDEUI_EXPORT CustomEditor( QWidget *repWidget, KLineEdit *edit )
+ KDEUI_EXPORT CustomEditor( TQWidget *repWidget, KLineEdit *edit )
: m_representationWidget( repWidget ),
m_lineEdit( edit ) {}
KDEUI_EXPORT CustomEditor( KComboBox *combo );
- KDEUI_EXPORT void setRepresentationWidget( QWidget *repWidget ) {
+ KDEUI_EXPORT void setRepresentationWidget( TQWidget *repWidget ) {
m_representationWidget = repWidget;
}
KDEUI_EXPORT void setLineEdit( KLineEdit *edit ) {
m_lineEdit = edit;
}
- KDEUI_EXPORT virtual QWidget *representationWidget() const {
+ KDEUI_EXPORT virtual TQWidget *representationWidget() const {
return m_representationWidget;
}
KDEUI_EXPORT virtual KLineEdit *lineEdit() const {
@@ -82,7 +82,7 @@ public:
}
protected:
- QWidget *m_representationWidget;
+ TQWidget *m_representationWidget;
KLineEdit *m_lineEdit;
};
@@ -107,7 +107,7 @@ public:
* it will be checked if you press the Add-button. It is not
* possible to enter items twice into the listbox.
*/
- KEditListBox(QWidget *parent = 0, const char *name = 0,
+ KEditListBox(TQWidget *parent = 0, const char *name = 0,
bool checkAtEntering=false, int buttons = All );
/**
* Create an editable listbox.
@@ -115,7 +115,7 @@ public:
* The same as the other constructor, additionally it takes
* @p title, which will be the title of the frame around the listbox.
*/
- KEditListBox(const QString& title, QWidget *parent = 0,
+ KEditListBox(const TQString& title, TQWidget *parent = 0,
const char *name = 0, bool checkAtEntering=false,
int buttons = All );
@@ -131,90 +131,90 @@ public:
* @see KURLRequester::customEditor()
* @since 3.1
*/
- KEditListBox( const QString& title,
+ KEditListBox( const TQString& title,
const CustomEditor &customEditor,
- QWidget *parent = 0, const char *name = 0,
+ TQWidget *parent = 0, const char *name = 0,
bool checkAtEntering = false, int buttons = All );
virtual ~KEditListBox();
/**
* Return a pointer to the embedded QListBox.
*/
- QListBox* listBox() const { return m_listBox; }
+ TQListBox* listBox() const { return m_listBox; }
/**
- * Return a pointer to the embedded QLineEdit.
+ * Return a pointer to the embedded TQLineEdit.
*/
KLineEdit* lineEdit() const { return m_lineEdit; }
/**
* Return a pointer to the Add button
*/
- QPushButton* addButton() const { return servNewButton; }
+ TQPushButton* addButton() const { return servNewButton; }
/**
* Return a pointer to the Remove button
*/
- QPushButton* removeButton() const { return servRemoveButton; }
+ TQPushButton* removeButton() const { return servRemoveButton; }
/**
* Return a pointer to the Up button
*/
- QPushButton* upButton() const { return servUpButton; }
+ TQPushButton* upButton() const { return servUpButton; }
/**
* Return a pointer to the Down button
*/
- QPushButton* downButton() const { return servDownButton; }
+ TQPushButton* downButton() const { return servDownButton; }
/**
- * See QListBox::count()
+ * See TQListBox::count()
*/
int count() const { return int(m_listBox->count()); }
/**
- * See QListBox::insertStringList()
+ * See TQListBox::insertStringList()
*/
- void insertStringList(const QStringList& list, int index=-1);
+ void insertStringList(const TQStringList& list, int index=-1);
/**
- * See QListBox::insertStringList()
+ * See TQListBox::insertStringList()
*/
- void insertStrList(const QStrList* list, int index=-1);
+ void insertStrList(const TQStrList* list, int index=-1);
/**
- * See QListBox::insertStrList()
+ * See TQListBox::insertStrList()
*/
- void insertStrList(const QStrList& list, int index=-1);
+ void insertStrList(const TQStrList& list, int index=-1);
/**
- * See QListBox::insertStrList()
+ * See TQListBox::insertStrList()
*/
void insertStrList(const char ** list, int numStrings=-1, int index=-1);
/**
- * See QListBox::insertItem()
+ * See TQListBox::insertItem()
*/
- void insertItem(const QString& text, int index=-1) {m_listBox->insertItem(text,index);}
+ void insertItem(const TQString& text, int index=-1) {m_listBox->insertItem(text,index);}
/**
* Clears both the listbox and the line edit.
*/
void clear();
/**
- * See QListBox::text()
+ * See TQListBox::text()
*/
- QString text(int index) const { return m_listBox->text(index); }
+ TQString text(int index) const { return m_listBox->text(index); }
/**
- * See QListBox::currentItem()
+ * See TQListBox::currentItem()
*/
int currentItem() const;
/**
- * See QListBox::currentText()
+ * See TQListBox::currentText()
*/
- QString currentText() const { return m_listBox->currentText(); }
+ TQString currentText() const { return m_listBox->currentText(); }
/**
* @returns a stringlist of all items in the listbox
*/
- QStringList items() const;
+ TQStringList items() const;
/**
* Clears the listbox and sets the contents to @p items
*
* @since 3.4
*/
- void setItems(const QStringList& items);
+ void setItems(const TQStringList& items);
/**
* Returns which buttons are visible
@@ -234,14 +234,14 @@ public:
* the parameter is the added string.
* @since 3.2
*/
- void added( const QString & text );
+ void added( const TQString & text );
/**
* This signal is emitted when the user removes a string from the list,
* the parameter is the removed string.
* @since 3.2
*/
- void removed( const QString & text );
+ void removed( const TQString & text );
protected slots:
//the names should be self-explaining
@@ -250,17 +250,17 @@ public:
void addItem();
void removeItem();
void enableMoveButtons(int index);
- void typedSomething(const QString& text);
+ void typedSomething(const TQString& text);
private:
- QListBox *m_listBox;
- QPushButton *servUpButton, *servDownButton;
- QPushButton *servNewButton, *servRemoveButton;
+ TQListBox *m_listBox;
+ TQPushButton *servUpButton, *servDownButton;
+ TQPushButton *servNewButton, *servRemoveButton;
KLineEdit *m_lineEdit;
//this is called in both ctors, to avoid code duplication
void init( bool checkAtEntering, int buttons,
- QWidget *representationWidget = 0L );
+ TQWidget *representationWidget = 0L );
protected:
virtual void virtual_hook( int id, void* data );
@@ -131,90 +131,90 @@ public:
virtual ~KEditListBox();
/**
- * Return a pointer to the embedded QListBox.
+ * Return a pointer to the embedded TQListBox.
*/